#!/usr/bin/perl -T
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# This Source Code Form is "Incompatible With Secondary Licenses", as
# defined by the Mozilla Public License, v. 2.0.

use 5.10.1;
use strict;
use warnings;

use lib qw(. lib);

use Bugzilla;
use Bugzilla::Constants;
use Bugzilla::BugMail;

my $dbh = Bugzilla->dbh;

my $list = $dbh->selectcol_arrayref(
  'SELECT bug_id FROM bugs
          WHERE (lastdiffed IS NULL OR lastdiffed < delta_ts)
            AND delta_ts < '
    . $dbh->sql_date_math('NOW()', '-', 30, 'MINUTE') . ' ORDER BY bug_id'
);

if (scalar(@$list) > 0) {
  Bugzilla->logger->info("OK, now attempting to send unsent mail");
  Bugzilla->logger->info(
    scalar(@$list) . " bugs found with possibly unsent mail.\n");
  foreach my $bugid (@$list) {
    my $start_time = time;
    Bugzilla->logger->info("Sending mail for bug $bugid...");
    ## RED HAT START 1468128 - catch errors and continue
    my $outputref;
    eval { $outputref = Bugzilla::BugMail::Send($bugid); };
    if ($@) {
      Bugzilla->logger->info("\tERROR: skipping because: $@\n");
      next;
    }
    ## RED HAT END 1468128
    if ($ARGV[0] && $ARGV[0] eq "--report") {
      Bugzilla->logger->info("Mail sent to:");
      Bugzilla->logger->info($_) foreach (sort @{$outputref->{sent}});
    }
    else {
      my $sent = scalar @{$outputref->{sent}};
      Bugzilla->logger->info("$sent mails sent.");
      Bugzilla->logger->info("Took " . (time - $start_time) . " seconds.\n");
      ## RED HAT START 1468128 - reset lastdiffed if there aren't actually any emails to send
      if ($sent == 0) {
        $dbh = Bugzilla->dbh();
        $dbh->do('UPDATE bugs SET lastdiffed = delta_ts WHERE bug_id = ?',
          undef, $bugid);
      }
      ## RED HAT END 1468128
    }
  }
  Bugzilla->logger->info("Unsent mail has been sent.");
}
