# -*- Mode: perl; indent-tabs-mode: nil -*-
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
# Copyright (C) 2012 Jolla Ltd.
# Contact: Pami Ketolainen <pami.ketolainen@jollamobile.com>

package Bugzilla::Extension::BugViewPlus::Params;

use strict;
use warnings;
use 5.10.1;

use Bugzilla::Config::Common;
use Bugzilla::Field;

sub get_param_list {
  my ($class) = @_;

  my @groups
    = sort @{Bugzilla->dbh->selectcol_arrayref("SELECT name FROM groups")};
  my ($old_group) = grep { $_ eq 'bvp_edit_description' } @groups;
  unshift @groups, '';

  my @param_list = (
    {
      name    => 'bvp_description_edit_group',
      desc    => 'User group that is allowed to edit bug descriptions',
      type    => 's',
      choices => \@groups,
      default => defined $old_group ? $old_group : '',
    },
    {
      name    => 'bvp_description_editable_types',
      desc    => 'Bug severities for which the description can be edited',
      type    => 'm',
      choices => get_legal_field_values('bug_severity'),
      default => []
    },
    {
      name    => 'bvp_linkify_severity',
      desc    => 'If true "<severity> #" will be linkified in bug comments',
      type    => 'b',
      default => 0,
    },

    {
      name    => 'bvp_simple_bug_view',
      desc    => 'Enable/disable the simplified bug view.',
      type    => 'b',
      default => 1
    },
    {
      name    => 'bvp_poll_wait',
      type    => 't',
      default => 60000,
      checker => \&check_numeric,
      desc    =>
        'The number of milliseconds between update polls on the bug edit page',
    },
    {
      name => 'bvp_simple_fields_selector',
      desc => 'CSS selector for bug fields shown in the simple bug view. '
        . 'Use a comma separated list of CSS selectors. The selectors '
        . 'are used to get the list of tr-elements containing the '
        . 'elements which will be shown in the simplified bug view.',
      type    => 't',
      default => '#bz_field_status,#field_container_product,'
        . '#field_container_component,select#priority,'
        . '#bz_show_bug_column_2 th:first,#bz_assignee_input'
    },
    {
      name    => 'bvp_inline_editor',
      desc    => 'Enable/disable the bug list inline editor.',
      type    => 'b',
      default => 1
    },
  );
  return @param_list;
}

1;

__END__

=head1 Description

Bugzilla::Extension:: ::Params - A module for specifying parameters to be added to the data/params.json file.

=head1 Parameters

=over 4

=item bvp_description_edit_group

User group that is allowed to edit bug descriptions.

=item bvp_description_editable_types

Bug severities for which the description can be edited.

=item bvp_linkify_severity

If true "<severity> #" will be linkified in bug comments.

=item bvp_simple_bug_view

Enable/disable the simplified bug view.

=item bvp_simple_fields_selector

CSS selector for bug fields shown in the simple bug view.
Use a comma separated list of CSS selectors. The selectors
are used to get the list of tr-elements containing the
elements which will be shown in the simplified bug view.

=item bvp_inline_editor

Enable/disable the bug list inline editor.

=back

