package Bugzilla::Extension::InlineHistory::Util;

use strict;
use warnings;
use 5.10.1;

use base qw(Exporter);
@Bugzilla::Extension::InlineHistory::Util::EXPORT = qw(
  _write_schema_cache
  _read_schema_cache
);

use Bugzilla;
use JSON;
use File::Slurp;

use constant CACHE_REQ_KEY => 'il_boolean_cols';
use constant CACHE_FILE    => 'il_boolean_cache';

sub _write_schema_cache {

  my $schema = Bugzilla->dbh->_bz_real_schema;

  my %cache;

  while (my ($tkey, $tdata) = each(%{$schema->{schema}})) {
    my $coldata = {@{$tdata->{FIELDS}}};

    while (my ($ckey, $cdata) = each(%$coldata)) {
      my $type = $coldata->{$ckey}->{TYPE};
      if (($type eq 'BOOLEAN') || ($type eq 'smallint')) {
        $cache{$tkey}->{$ckey} = 1;
      }
    }
  }

  my $filepath = Bugzilla->bz_locations()->{'datadir'} . '/' . CACHE_FILE;
  my $json_txt = to_json(\%cache);
  write_file($filepath, $json_txt);

  return;
}

sub _read_schema_cache {
  return Bugzilla->request_cache->{+CACHE_REQ_KEY}
    if exists Bugzilla->request_cache->{+CACHE_REQ_KEY};

  my $filepath = Bugzilla->bz_locations()->{'datadir'} . '/' . CACHE_FILE;

  my $file = File::Slurp::read_file($filepath, err_mode => 'quiet');

  # $file will be undef on any error.
  unless (defined($file)) {
    Bugzilla->request_cache->{+CACHE_REQ_KEY} = undef;
    return;
  }

  my $schema = JSON::from_json($file);

  Bugzilla->request_cache->{+CACHE_REQ_KEY} = $schema;

  return $schema;
}

1;
