-- Bug 1265486.  This script will rebuild the full text search indexes

DROP INDEX IF EXISTS comments_vect_idx;
DROP INDEX IF EXISTS comments_noprivate_vect_idx;
DROP INDEX IF EXISTS short_desc_vect;

CREATE OR REPLACE FUNCTION public.update_fulltext()
 RETURNS integer
AS $$
DECLARE
    rowdata bugs_fulltext%ROWTYPE;
    count integer;
    printer integer;
BEGIN
    count := 0;
    printer := 0;

    FOR rowdata IN SELECT * FROM bugs_fulltext WHERE comments IS NOT NULL ORDER BY bug_id LOOP
        EXECUTE 'UPDATE bugs_fulltext SET comments_vect = to_tsvector(''english'','
         || quote_literal(escape_special_tokens(rowdata.comments)) || ') WHERE bug_id = ' || rowdata.bug_id;
        count = count + 1;
        printer = printer + 1;
        IF printer >= 1000 THEN
            RAISE NOTICE '(comments) Bug %', rowdata.bug_id;
            printer := 0;
        END IF;
    END LOOP;

    printer := 0;
    FOR rowdata IN SELECT * FROM bugs_fulltext WHERE comments_noprivate IS NOT NULL ORDER BY bug_id LOOP
        EXECUTE 'UPDATE bugs_fulltext SET comments_noprivate_vect = to_tsvector(''english'','
         || quote_literal(escape_special_tokens(rowdata.comments_noprivate)) || ') WHERE bug_id = ' || rowdata.bug_id;
        count = count + 1;
        printer = printer + 1;
        IF printer >= 1000 THEN
            RAISE NOTICE '(comments_noprivate) Bug %', rowdata.bug_id;
            printer := 0;
        END IF;
    END LOOP;

    printer := 0;
    FOR rowdata IN SELECT * FROM bugs_fulltext WHERE short_desc IS NOT NULL ORDER BY bug_id LOOP
        EXECUTE 'UPDATE bugs_fulltext SET short_desc_vect = to_tsvector(''english'','
         || quote_literal(escape_special_tokens(rowdata.short_desc)) || ') WHERE bug_id = ' || rowdata.bug_id;
        count = count + 1;
        printer = printer + 1;
        IF printer >= 1000 THEN
            RAISE NOTICE '(short_desc) Bug %', rowdata.bug_id;
            printer := 0;
        END IF;
    END LOOP;

    RETURN count;
END;
$$  LANGUAGE plpgsql;

SELECT public.update_fulltext();

DROP FUNCTION update_fulltext();

CREATE INDEX comments_vect_idx ON bugs_fulltext USING gin(comments_vect);
CREATE INDEX comments_noprivate_vect_idx ON bugs_fulltext USING gin(comments_noprivate_vect);
CREATE INDEX short_desc_vect ON bugs_fulltext USING gin(short_desc_vect);
