# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

package Bugzilla::Extension::RedHat::Config;

use strict;
use warnings;
use 5.10.1;

use Bugzilla::Config::Common;

sub get_param_list {

  my @param_list = (
    {name => 'rpc_log_args',     type => 'b', default => 0,},
    {name => 'rh_radius_groups', type => 's', default => '',},
  );

  return @param_list;
}

1;

__END__

=head1 Description

Bugzilla::Extension::RedHat::Config - A module for specifying parameters to be
added to the data/params.json file.

=head1 Parameters

=over 4

=item LDAPMXBaseDN

The BaseDN for authentinticating to (e.g. uid=me,ou=me,dc=Company). 

=item LDAPMXSearchDN

The DN for authenticating mail aliases against (e.g. ou=mx,o=Company).

=item LDAPMXmailattribute

The LDAP attribute to compare login_name to.

=item LDAPMXserver

The LDAP server to source MX records from.

=item announcehtml

If this field is non-empty, then Bugzilla will display whatever is in this
field at the top of every HTML page.  The HTML you put in this field is not
wrapped or enclosed in anything; you might want to wrap it inside a C<< <div>
>>.  Give the div C<class="message"> to apply the message box formatting.

=item bugzilla_term

The term to use on the site and in the documentation for this Bugzilla installation.

=item duplicate_warn_override

Provide a warning when the 'duplicate of' bug is for a different product or
version?

=item expired_search_time

This will unshare a shared saved search if it has not been used within the
specified time frame. The user will be sent an email informing them that their
search is no longer being shared.

=item flag_type_categories

A comma separated list of flag type categories. Start the list with a comma if
you want an empty value as an option.

=item force_secure_cookies

Always set the secure param for cookies even if ssl redirect is not enabled for
this Bugzilla installation. Some systems reside behind proxy servers that
automatically redirect to https: regardless if Bugzilla is configured to do so.

=item group_categories

A comma separated list of group categories. Start the list with a comma if you
want an empty value as an option.

=item inbound_proxies

When inbound traffic to Bugzilla goes through a proxy, Bugzilla thinks that the
IP address of every single user is the IP address of the proxy. If you enter a
comma-separated list of IPs in this parameter, then Bugzilla will trust any
C<X-Forwarded-For> header sent from those IPs, and use the value of
that header as the end user's IP address.

=item log4perl_config

A L<Log::Log4perl> configuration string to control log format.

=item login_lockout_interval

This defines the time that the account with the maximum login attempts will be
locked out for in minutes.

=item long_query_timeout

Certain scripts such as buglist.cgi can create very large SQL queries that
sometimes take a long time to execute and will cause database issues. This
value is the total number of seconds that a query is allowed to run before it
is killed off. Set to 0 to disable.

=item mail_errors_to

The e-mail address that system errors are sent to.

=item max_login_attempts

This defines the maximum number of failed login attempts before locking account
from it's IP address.

=item proxy_url

Bugzilla may have to access the web to get notifications about new releases,
see the C<upgrade_notification> parameter. In case you are behind a proxy, it
may be necessary to enter its URL if the web server group cannot access the
HTTP_PROXY environment variable. If you have to authenticate, use the
C<http://user:pass@proxy_url/> syntax.

=item rh_radius_groups

List of groups that require RADIUS auth.

=item rpc_log_args

Log arguments for RPC calls to the log? Will not log password/apikey/cookies/etc.

=item second_shadowdb

If non-empty, then this is the name of another database in which Bugzilla will
use as a read-only copy of everything. This is done so that long slow read-only
operations can be used against this db, and not lock up things for everyone
else. This database is on the second_shadowdbhost, and must exist. Bugzilla
does not update it, if you use this parameter, then you need to set up
replication for your database.

=item second_shadowdbhost

The host the second shadow database is on.

=item second_shadowdbport

The port the second shadow database is on. Ignored if second_shadowdbhost is
blank. Note: if the host is the local machine, then MySQL will ignore this
setting, and you must specify a socket below.

=item second_shadowdbsock

The socket used to connect to the second shadow database, if the host is the
local machine. This setting is required because MySQL ignores the port
specified by the client and connects using its compiled-in socket path (on unix
machines) when connecting from a client to a local server. If you leave this
blank, and have the database on localhost, then the second_shadowdbport will be
ignored.

=item shutdownhtml

If this field is non-empty, then Bugzilla will be completely disabled and this
text will be displayed instead of all the Bugzilla pages.

=item usedocscontact

Do you wish to use the Docs Contact field?

=item usetargetrelease

Do you wish to use the Target Release field?

=item utf8

Use UTF-8 (Unicode) encoding for all text in Bugzill. New installations should
set this to true to avoid character encoding problems. B<Existing databases
should set this to true only after the data has been converted from existing
legacy character encodings to UTF-8, using the 'contrib/recode.pl' script>. 

Note that if you  turn this parameter from "off" to "on", you must re-run
checksetup.pl immediately afterward.

=back

