# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

package Bugzilla::Extension::RedHat::WebService::Field;

use strict;
use warnings;
use 5.10.1;
use base qw(Bugzilla::WebService);
use Bugzilla::Product;
use Bugzilla::Component;
use Bugzilla::Field;
use Bugzilla::User;
use Bugzilla::Constants;
use Bugzilla::Error;
use Bugzilla::Util qw(trim);
use Bugzilla::WebService::Util qw(validate);

use constant PUBLIC_METHODS => qw(
  legal_values
);

# function to return an array of field id and product + field name
# exmaple of how it will be called:
# $call = $rpc->call( 'Component.get_all');

sub legal_values {
  my ($self, $params) = validate(@_, 'id');

  my $user = Bugzilla->login(LOGIN_REQUIRED);
  $user->in_group('admin')
    || ThrowUserError("auth_failure",
    {group => "admin", action => "edit", object => "fields"});

  my $field = Bugzilla::Field->new($params->{id}[0]);

  my @legal_values;

  if ($field->{name} eq 'component') {
    foreach my $lv (@{$field->legal_values}) {
      my $product = Bugzilla::Product->new($lv->product_id);
      push(@legal_values, [$lv->id, $product->name . ": " . $lv->name]);
    }
  }
  else {
    foreach my $lv (@{$field->legal_values}) {
      push(@legal_values, [$lv->id, $lv->name]);
    }
  }

  return (\@legal_values);
}


1;

__END__

=head1 NAME

Bugzilla::WebService::Field - API for handling Custom Fields.

=head1 DESCRIPTION

This part of the Bugzilla API allows you to fetch field details.

=head1 METHODS

See L<Bugzilla::WebService> for a description of what B<STABLE>, B<UNSTABLE>,
and B<EXPERIMENTAL> mean, and for more description about error codes.

=over

=item C<legal_values> B<UNSTABLE>

Fetches all the legal values for the supplied field Id.

=back

=cut

